==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterClaimConditionBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition,io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionBuilder>{
  public ClusterClaimConditionBuilder() {
    this(false);
  }
  public ClusterClaimConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterClaimCondition(), validationEnabled);
  }
  public ClusterClaimConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterClaimCondition(), validationEnabled);
  }
  public ClusterClaimConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition instance) {
    this(instance,false);
  }
  public ClusterClaimConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterClaimConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition build() {
    ClusterClaimCondition buildable = new ClusterClaimCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterClaimConditionBuilder that = (ClusterClaimConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.3.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterClaimConditionBuilder extends ClusterClaimConditionFluentImpl<ClusterClaimConditionBuilder> implements VisitableBuilder<ClusterClaimCondition,ClusterClaimConditionBuilder>{
  public ClusterClaimConditionBuilder() {
    this(false);
  }
  public ClusterClaimConditionBuilder(Boolean validationEnabled) {
    this(new ClusterClaimCondition(), validationEnabled);
  }
  public ClusterClaimConditionBuilder(ClusterClaimConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimConditionBuilder(ClusterClaimConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterClaimCondition(), validationEnabled);
  }
  public ClusterClaimConditionBuilder(ClusterClaimConditionFluent<?> fluent,ClusterClaimCondition instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimConditionBuilder(ClusterClaimConditionFluent<?> fluent,ClusterClaimCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimConditionBuilder(ClusterClaimCondition instance) {
    this(instance,false);
  }
  public ClusterClaimConditionBuilder(ClusterClaimCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterClaimConditionFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterClaimCondition build() {
    ClusterClaimCondition buildable = new ClusterClaimCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
